﻿#Region "LICENSE"
'
' Copyright (c) Microncode.com
' 
' This source is subject to the Microsoft Public License. 
' See https://opensource.org/licenses/ms-pl.html.
' All other rights reserved. 
' 
' THIS CODE And INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
' EITHER EXPRESSED Or IMPLIED, INCLUDING BUT Not LIMITED TO THE IMPLIED 
' WARRANTIES OF MERCHANTABILITY And/Or FITNESS FOR A PARTICULAR PURPOSE. 
'
#End Region

''' <summary>
''' The main example of using the CSID3Tags library.
''' </summary>
Public Class frmID3Tags

    Friend WithEvents ID3Tags1 As CSID3Tags.ID3Tags

    ''' <summary>
    ''' Open the multimedia file. The supported format are: avi, mp3, mpc, mp4, asf, aiff, aif, aifc, tta, wv, ogg, flac, spx, opus, ape, xiph, wma, jpg, jpeg, png, mpg, mpeg and many other multimedia files.
    ''' </summary>
    ''' <param name="multimedia_file"></param>
    Public Sub LoadFile(ByVal multimedia_file As String)
        Try

            'Clean the form controls:
            ClearAllFields()

            'Open the media file:
            ID3Tags1.Open(txtMediaFile.Text)

            'Get the ID3 tags:
            txtTagTitle.Text = ID3Tags1.TagTitle
            txtTagAlbum.Text = ID3Tags1.TagAlbum
            txtTagComment.Text = ID3Tags1.TagComment
            txtTagCopyright.Text = ID3Tags1.TagCopyright
            txtTagYear.Text = ID3Tags1.TagYear
            txtTagLyrics.Text = ID3Tags1.TagLyrics

            cboTagRating.Text = ID3Tags1.RatingStars.ToString()

            DisplayGenres()
            DisplayArtists()
            DisplayImages()
            DisplayComposers()

        Catch ex As Exception
            Console.WriteLine(ex.Message)
        Finally
        End Try
    End Sub

    ''' <summary>
    ''' Clear all the text boxes fields in the form
    ''' </summary>
    Private Sub ClearAllFields()

        txtTagTitle.Text = ""
        txtTagAlbum.Text = ""
        txtTagComment.Text = ""
        txtTagCopyright.Text = ""
        txtTagYear.Text = ""
        txtTagLyrics.Text = ""

        lstTagArtists.Items.Clear()
        lstTagComposers.Items.Clear()
        lstTagGenres.Items.Clear()
        lstTagImages.Items.Clear()

        picImage.Image = Nothing

    End Sub

    ''' <summary>
    ''' Form load.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub frmID3Tags_Load(sender As Object, e As EventArgs) Handles MyBase.Load

        Me.ID3Tags1 = New CSID3Tags.ID3Tags()

        ID3Tags1.UserName = "Your email"
        ID3Tags1.UserKey = "Your registration key"

    End Sub

    ''' <summary>
    ''' Open multimedia file dialog box.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdOpenMediaFile_Click(sender As Object, e As EventArgs) Handles cmdOpenMediaFile.Click

        If openFileDialog1.ShowDialog() = System.Windows.Forms.DialogResult.OK Then
            txtMediaFile.Text = openFileDialog1.FileName
            LoadFile(txtMediaFile.Text)
        End If

    End Sub

    ''' <summary>
    ''' Save the text boxes fields of the form to the selected multimedia file.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdSave_Click(sender As Object, e As EventArgs) Handles cmdSave.Click

        Try
            'Set the title
            ID3Tags1.TagTitle = txtTagTitle.Text

            'Set the album name:
            ID3Tags1.TagAlbum = txtTagAlbum.Text

            'Set the comment:
            ID3Tags1.TagComment = txtTagComment.Text

            'Set the copyright
            ID3Tags1.TagCopyright = txtTagCopyright.Text

            'Set the lyrics:
            ID3Tags1.TagLyrics = txtTagLyrics.Text

            'Set the rating tag:
            Dim floatrating As Single
            If Not Single.TryParse(cboTagRating.Text, floatrating) Then
                floatrating = 0
            End If
            ID3Tags1.RatingStars = floatrating

            'Set the year:
            ID3Tags1.TagYear = txtTagYear.Text

            'Save:
            ID3Tags1.[Set]()

        Catch ex As Exception
            Console.WriteLine(ex.Message)
        Finally
        End Try

    End Sub

    ''' <summary>
    ''' Select and display the image from the images list when the selected index has been changed.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub lstTagImages_SelectedIndexChanged(sender As Object, e As EventArgs) Handles lstTagImages.SelectedIndexChanged

        If lstTagImages.Items.Count > 0 Then picImage.Image = ID3Tags1.TagImages(lstTagImages.SelectedIndex).Image

    End Sub

    ''' <summary>
    ''' Select and display the image from the images list when the user clicked on an item in the images list.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub lstTagImages_Click(sender As Object, e As EventArgs) Handles lstTagImages.Click

        If lstTagImages.Items.Count > 0 Then picImage.Image = ID3Tags1.TagImages(lstTagImages.SelectedIndex).Image

    End Sub

#Region "Artists"

    Private Sub DisplayArtists()
        lstTagArtists.Items.Clear()
        If ID3Tags1.TagArtists Is Nothing Then Return

        For Each artist As String In ID3Tags1.TagArtists
            lstTagArtists.Items.Add(artist)
        Next

        If lstTagArtists.Items.Count > 0 Then lstTagArtists.SelectedIndex = 0
    End Sub

    Private Sub cmdTagArtistsAdd_Click(sender As Object, e As EventArgs) Handles cmdTagArtistsAdd.Click

        Dim value As String = ""

        If Core.InputBox("Add artist", "Artist name:", value) = DialogResult.OK Then
            ID3Tags1.TagArtists.Add(value)
        End If

        DisplayArtists()

    End Sub

    Private Sub cmdTagArtistsRemove_Click(sender As Object, e As EventArgs) Handles cmdTagArtistsRemove.Click

        If lstTagArtists.Items.Count = 0 Then Return

        ID3Tags1.TagArtists.RemoveAt(lstTagArtists.SelectedIndex)
        DisplayArtists()

    End Sub

    Private Sub cmdTagArtistsUp_Click(sender As Object, e As EventArgs) Handles cmdTagArtistsUp.Click

        Dim selected_index As Integer = 0

        If lstTagArtists.Items.Count = 0 OrElse lstTagArtists.SelectedIndex = 0 Then Return

        selected_index = lstTagArtists.SelectedIndex
        ID3Tags1.TagArtists = Core.Switch(ID3Tags1.TagArtists, selected_index, selected_index - 1)

        DisplayArtists()

        lstTagArtists.SelectedIndex = selected_index - 1

    End Sub

    Private Sub cmdTagArtistsDown_Click(sender As Object, e As EventArgs) Handles cmdTagArtistsDown.Click

        Dim selected_index As Integer = 0

        If lstTagArtists.SelectedIndex = (lstTagArtists.Items.Count - 1) Then Return

        selected_index = lstTagArtists.SelectedIndex
        ID3Tags1.TagArtists = Core.Switch(ID3Tags1.TagArtists, selected_index, selected_index + 1)

        DisplayArtists()

        lstTagArtists.SelectedIndex = selected_index + 1

    End Sub

#End Region

#Region "Composers"

    ''' <summary>
    ''' Add all the composers to the Composers list.
    ''' </summary>
    Private Sub DisplayComposers()

        lstTagComposers.Items.Clear()
        If ID3Tags1.TagComposers Is Nothing Then Return

        For Each composer As String In ID3Tags1.TagComposers
            lstTagComposers.Items.Add(composer)
        Next

        If lstTagComposers.Items.Count > 0 Then lstTagComposers.SelectedIndex = 0

    End Sub

    ''' <summary>
    ''' Add new Composer
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdTagComposersAdd_Click(sender As Object, e As EventArgs) Handles cmdTagComposersAdd.Click

        Dim value As String = ""

        If Core.InputBox("Add composer", "Composer name:", value) = DialogResult.OK Then
            ID3Tags1.TagComposers.Add(value)
        End If

        DisplayComposers()

    End Sub

    ''' <summary>
    ''' Remove the selected Composer
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdTagComposersRemove_Click(sender As Object, e As EventArgs) Handles cmdTagComposersRemove.Click

        If lstTagComposers.Items.Count = 0 Then Return

        ID3Tags1.TagComposers.RemoveAt(lstTagComposers.SelectedIndex)
        DisplayComposers()

    End Sub

    ''' <summary>
    ''' Move the selected composer index in the list one stage up.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdTagComposersUp_Click(sender As Object, e As EventArgs) Handles cmdTagComposersUp.Click

        Dim selected_index As Integer = 0

        If lstTagComposers.Items.Count = 0 OrElse lstTagComposers.SelectedIndex = 0 Then Return

        selected_index = lstTagComposers.SelectedIndex
        ID3Tags1.TagComposers = Core.Switch(ID3Tags1.TagComposers, selected_index, selected_index - 1)

        DisplayComposers()

        lstTagComposers.SelectedIndex = selected_index - 1

    End Sub

    ''' <summary>
    ''' Move the selected composer index in the list one stage down.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdTagComposersDown_Click(sender As Object, e As EventArgs) Handles cmdTagComposersDown.Click

        Dim selected_index As Integer = 0

        If lstTagComposers.SelectedIndex = (lstTagComposers.Items.Count - 1) Then Return

        selected_index = lstTagComposers.SelectedIndex
        ID3Tags1.TagComposers = Core.Switch(ID3Tags1.TagComposers, selected_index, selected_index + 1)

        DisplayComposers()

        lstTagComposers.SelectedIndex = selected_index + 1

    End Sub

#End Region

#Region "Genres"

    Private Sub DisplayGenres()

        'Clear the list
        lstTagGenres.Items.Clear()

        If ID3Tags1.TagGenres Is Nothing Then Return

        'Add all the items to the list
        For Each genre As String In ID3Tags1.TagGenres
            lstTagGenres.Items.Add(genre)
        Next

        'Select the first item
        If lstTagGenres.Items.Count > 0 Then lstTagGenres.SelectedIndex = 0

    End Sub

    Private Sub cmdTagGenresAdd_Click(sender As Object, e As EventArgs) Handles cmdTagGenresAdd.Click

        If cboTagGenres.Text IsNot "" Then ID3Tags1.TagGenres.Add(cboTagGenres.Text)

        DisplayGenres()

    End Sub

    Private Sub cmdTagGenresRemove_Click(sender As Object, e As EventArgs) Handles cmdTagGenresRemove.Click

        If lstTagGenres.Items.Count = 0 Then Return

        ID3Tags1.TagGenres.RemoveAt(lstTagGenres.SelectedIndex)

        DisplayGenres()

    End Sub

    Private Sub cmdTagGenresUp_Click(sender As Object, e As EventArgs) Handles cmdTagGenresUp.Click

        Dim selected_index As Integer = 0

        If lstTagGenres.Items.Count = 0 OrElse lstTagGenres.SelectedIndex = 0 Then Return

        selected_index = lstTagGenres.SelectedIndex
        ID3Tags1.TagGenres = Core.Switch(ID3Tags1.TagGenres, selected_index, selected_index - 1)

        DisplayGenres()

        lstTagGenres.SelectedIndex = selected_index - 1

    End Sub

    Private Sub cmdTagGenresDown_Click(sender As Object, e As EventArgs) Handles cmdTagGenresDown.Click

        Dim selected_index As Integer = 0

        If lstTagGenres.SelectedIndex = (lstTagGenres.Items.Count - 1) Then Return

        selected_index = lstTagGenres.SelectedIndex
        ID3Tags1.TagGenres = Core.Switch(ID3Tags1.TagGenres, selected_index, selected_index + 1)

        DisplayGenres()

        lstTagGenres.SelectedIndex = selected_index + 1

    End Sub

#End Region

#Region "Images"

    Private Sub DisplayImages()

        'Clear the list
        lstTagImages.Items.Clear()

        If ID3Tags1.TagImages Is Nothing Then Return

        'Add all the items to the list
        For Each img In ID3Tags1.TagImages
            lstTagImages.Items.Add(img.Mine_Type & vbTab & img.Type & vbTab & img.Description)
        Next

        'Select the first item
        If lstTagImages.Items.Count > 0 Then
            lstTagImages.SelectedIndex = 0
            picImage.Image = ID3Tags1.TagImages(lstTagImages.SelectedIndex).Image
        End If

    End Sub

    ''' <summary>
    ''' Add an image to the images tag of the multimedia file. You can add an image from a file (AddImageFromFile) or from an Image object.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdTagImagesAdd_Click(sender As Object, e As EventArgs) Handles cmdTagImagesAdd.Click

        openFileDialog1.Filter = "(Image Files)|*.jpg;*.jpeg;*.png|jpg, | *.jpg|jpeg, | *.jpeg|png, | *.png"

        If openFileDialog1.ShowDialog() = System.Windows.Forms.DialogResult.OK Then

            'From a file:
            Dim img As Image = ID3Tags1.AddImageFromFile(openFileDialog1.FileName)
            Me.picImage.Image = img

            'From an Image object:
            'Dim image As Image = Image.FromFile(openFileDialog1.FileName)
            'Me.picImage.Image = image
            'Dim minetype As String = Core.GetMineType(image)
            'Dim imgobj As ImageTag = New ImageTag(image, minetype, "iD3Tags1.Tagcom", CSID3TagsLib.ImageType.FrontCover)
            'ID3Tags1.TagImages.Add(imgobj)

        End If

        DisplayImages()
    End Sub

    Private Sub cmdTagImagesRemove_Click(sender As Object, e As EventArgs) Handles cmdTagImagesRemove.Click

        If lstTagImages.Items.Count = 0 Then Return

        ID3Tags1.TagImages.RemoveAt(lstTagImages.SelectedIndex)

        DisplayImages()

    End Sub

    Private Sub cmdTagImagesUp_Click(sender As Object, e As EventArgs) Handles cmdTagImagesUp.Click

        Dim selected_index As Integer = 0

        If lstTagImages.Items.Count = 0 OrElse lstTagImages.SelectedIndex = 0 Then Return

        selected_index = lstTagImages.SelectedIndex
        ID3Tags1.TagImages = Core.Switch(ID3Tags1.TagImages, selected_index, selected_index - 1)

        DisplayImages()

        lstTagImages.SelectedIndex = selected_index - 1

    End Sub

    Private Sub cmdTagImagesDown_Click(sender As Object, e As EventArgs) Handles cmdTagImagesDown.Click

        Dim selected_index As Integer = 0

        If lstTagImages.SelectedIndex = (lstTagImages.Items.Count - 1) Then Return

        selected_index = lstTagImages.SelectedIndex
        ID3Tags1.TagImages = Core.Switch(ID3Tags1.TagImages, selected_index, selected_index + 1)

        DisplayImages()

        lstTagImages.SelectedIndex = selected_index + 1

    End Sub

#End Region

    ''' <summary>
    ''' Clear all the ID3 tags from the multimedia file.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdClearAllTags_Click(sender As Object, e As EventArgs) Handles cmdClearAllTags.Click

        If txtMediaFile.Text = "" Then Return

        Dim dialogResult As DialogResult = MessageBox.Show("'Clear All Tags' will delete all the ID3 tags in the multimedia file, continue?", "Warning", MessageBoxButtons.OKCancel)

        If dialogResult = DialogResult.OK Then
            ID3Tags1.ClearAllTags()
            LoadFile(txtMediaFile.Text)
            picImage.Image = Nothing
        End If

    End Sub

    ''' <summary>
    ''' Check the license.
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    Private Sub cmdOrderLicense_Click(sender As Object, e As EventArgs) Handles cmdOrderLicense.Click

        ' In order to get your own UserName and RegKey and to distribute this library
        ' with your own projects for commercial or any other purpose, please order a license at:
        ' https://www.microncode.com/developers/cs-id3-tags/?cmd=order

        System.Diagnostics.Process.Start("https://www.microncode.com/developers/cs-id3-tags/?cmd=order")

    End Sub

End Class
